==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/button/TemplateMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class TemplateMessageBuilder {
    private java.lang.String id;
    private it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate content;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredFourRowTemplate> highlyStructuredFourRowTemplateFormat;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate> hydratedFourRowTemplateFormat;
    private java.util.Optional<it.auties.whatsapp.model.message.button.InteractiveMessage> interactiveMessageFormat;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;

    public TemplateMessageBuilder() {
        id = null;
        content = null;
        highlyStructuredFourRowTemplateFormat = java.util.Optional.empty();
        hydratedFourRowTemplateFormat = java.util.Optional.empty();
        interactiveMessageFormat = java.util.Optional.empty();
        contextInfo = java.util.Optional.empty();
    }

    public TemplateMessageBuilder id(java.lang.String id) {
        this.id = id;
        return this;
    }
    public TemplateMessageBuilder content(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate content) {
        this.content = content;
        return this;
    }
    public TemplateMessageBuilder highlyStructuredFourRowTemplateFormat(java.util.Optional<it.auties.whatsapp.model.button.template.hsm.HighlyStructuredFourRowTemplate> highlyStructuredFourRowTemplateFormat) {
        this.highlyStructuredFourRowTemplateFormat = highlyStructuredFourRowTemplateFormat;
        return this;
    }
    public TemplateMessageBuilder highlyStructuredFourRowTemplateFormat(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredFourRowTemplate highlyStructuredFourRowTemplateFormat) {
        this.highlyStructuredFourRowTemplateFormat = java.util.Optional.ofNullable(highlyStructuredFourRowTemplateFormat);
        return this;
    }
    public TemplateMessageBuilder hydratedFourRowTemplateFormat(java.util.Optional<it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate> hydratedFourRowTemplateFormat) {
        this.hydratedFourRowTemplateFormat = hydratedFourRowTemplateFormat;
        return this;
    }
    public TemplateMessageBuilder hydratedFourRowTemplateFormat(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate hydratedFourRowTemplateFormat) {
        this.hydratedFourRowTemplateFormat = java.util.Optional.ofNullable(hydratedFourRowTemplateFormat);
        return this;
    }
    public TemplateMessageBuilder interactiveMessageFormat(java.util.Optional<it.auties.whatsapp.model.message.button.InteractiveMessage> interactiveMessageFormat) {
        this.interactiveMessageFormat = interactiveMessageFormat;
        return this;
    }
    public TemplateMessageBuilder interactiveMessageFormat(it.auties.whatsapp.model.message.button.InteractiveMessage interactiveMessageFormat) {
        this.interactiveMessageFormat = java.util.Optional.ofNullable(interactiveMessageFormat);
        return this;
    }
    public TemplateMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public TemplateMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }

    public it.auties.whatsapp.model.message.button.TemplateMessage build() {
        return new it.auties.whatsapp.model.message.button.TemplateMessage(id, content, highlyStructuredFourRowTemplateFormat, hydratedFourRowTemplateFormat, interactiveMessageFormat, contextInfo);
    }
}

==> cobalt-0.0.4-sources.jar: it/auties/whatsapp/model/message/button/TemplateMessageBuilder.java <==
package it.auties.whatsapp.model.message.button;

public class TemplateMessageBuilder {
    private java.lang.String id;
    private it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate content;
    private it.auties.whatsapp.model.button.template.hsm.HighlyStructuredFourRowTemplate highlyStructuredFourRowTemplateFormat;
    private it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate hydratedFourRowTemplateFormat;
    private it.auties.whatsapp.model.message.button.InteractiveMessage interactiveMessageFormat;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;

    public TemplateMessageBuilder() {
        id = null;
        content = null;
        highlyStructuredFourRowTemplateFormat = null;
        hydratedFourRowTemplateFormat = null;
        interactiveMessageFormat = null;
        contextInfo = null;
    }

    public TemplateMessageBuilder id(java.lang.String id) {
        this.id = id;
        return this;
    }
    public TemplateMessageBuilder content(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate content) {
        this.content = content;
        return this;
    }
    public TemplateMessageBuilder highlyStructuredFourRowTemplateFormat(it.auties.whatsapp.model.button.template.hsm.HighlyStructuredFourRowTemplate highlyStructuredFourRowTemplateFormat) {
        this.highlyStructuredFourRowTemplateFormat = highlyStructuredFourRowTemplateFormat;
        return this;
    }
    public TemplateMessageBuilder hydratedFourRowTemplateFormat(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate hydratedFourRowTemplateFormat) {
        this.hydratedFourRowTemplateFormat = hydratedFourRowTemplateFormat;
        return this;
    }
    public TemplateMessageBuilder interactiveMessageFormat(it.auties.whatsapp.model.message.button.InteractiveMessage interactiveMessageFormat) {
        this.interactiveMessageFormat = interactiveMessageFormat;
        return this;
    }
    public TemplateMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }

    public it.auties.whatsapp.model.message.button.TemplateMessage build() {
        return new it.auties.whatsapp.model.message.button.TemplateMessage(id, content, highlyStructuredFourRowTemplateFormat, hydratedFourRowTemplateFormat, interactiveMessageFormat, contextInfo);
    }
}
